@@ -29,6 +29,7 @@
 #include "fahrplan_utils.h"
 #include "fahrplan_gui.h"
 #include "fahrplan_parser.h"
+#include "fahrplan_parser_gisgraphy.h"
 
 /**
  * OnClick Event for a HildonButton
@@ -47,7 +48,9 @@ void onAboutClicked(HildonButton * button, AppData *data) {
 	strcat(infoLabel, "with contributions by\n");
 	strcat(infoLabel, "<i>hcm</i> (various patches)\n");
 	strcat(infoLabel, "<i>thp</i> (hildon themed buttons)\n");
-	strcat(infoLabel, "<i>qwerty12</i> (two min crash)");
+	strcat(infoLabel, "<i>qwerty12</i> (two min crash)\n");
+	strcat(infoLabel, "<i>qbast</i> (gisgraphy backend)");
+
 
 	hildon_banner_show_information_with_markup(
 			GTK_WIDGET(data->journeyWindow),
@@ -160,14 +163,28 @@ void onGetStationByGPSClicked(HildonButton * button, AppData *data) {
 
 			GArray *result = getStationsByGPS(poslong, poslat, data);
 
-			/* nothing found */
-			if (result && !g_array_index(result, gchar*, 0)) {
+			/* Nothing found try gisgraphy backend */
+			if (result==NULL || result->len == 0) {
 
 				hildon_banner_show_information(
 						GTK_WIDGET(data->journeyWindow),
 						NULL,
-						_("No Stations found near your location!"));
+						_("Trying gisgraphy to find your city by location"));
 
+				gchar *cityname = getCityNameByGPS(data->currentGPSDevice->fix->longitude, data->currentGPSDevice->fix->latitude);
+
+				if (cityname==NULL) {
+
+					hildon_banner_show_information(
+							GTK_WIDGET(data->journeyWindow),
+							NULL,
+							_("No Stations found near your location!"));
+				} else {
+
+					GArray *result = getStationsByName(cityname, data);
+
+					initStationPickerForArray(result, data);
+				}
 			} else {
 
 				initStationPickerForArray(result, data);
