@@ -35,7 +35,7 @@
 GArray * getStationsByName_mobilebahnde(gchar * stationName) {
 
 	gchar * postData =	g_strdup_printf("REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0G=%s", stationName);
-	gchar * url      = "http://mobile.bahn.de/bin/mobil/query.exe/dox?rt=1&use_realtime_filter=1&searchMode=NORMAL";
+	gchar * url      = "http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&searchMode=NORMAL";
 	gchar * result   = performCurlRequest(url, postData);
 
 	if (!result) {
@@ -135,7 +135,7 @@ GArray * getStationsByName_mobilebahnde(gchar * stationName) {
  */
 GArray * getStationsByGPS_mobilebahnde(gint longitude, gint latitude) {
 
-	gchar * url      = g_strdup_printf("http://mobile.bahn.de/bin/mobil/query.exe/dox?rt=1&use_realtime_filter=1&stationNear=1&look_x=%d&look_y=%d&performLocating=2&tpl=stopsnear&look_maxdist=1000&look_stopclass=1023&n=1", longitude, latitude);
+	gchar * url      = g_strdup_printf("http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&stationNear=1&look_x=%d&look_y=%d&performLocating=2&tpl=stopsnear&look_maxdist=1000&look_stopclass=1023&n=1", longitude, latitude);
 	gchar * result   = performCurlRequest(url, NULL);
 
 	if (!result) {
@@ -243,7 +243,7 @@ ResultInfo * getJourneyDataByUrl_mobilebahnde(gchar *url) {
 ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation, gchar *toStation, gint day, gint month, gint year, gint hour, gint minutes, gint options) {
 
 	gchar * postData = g_strdup_printf("REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0G=%s&REQ0JourneyStopsS0ID=&REQ0JourneyStopsZ0A=1&REQ0JourneyStopsZ0G=%s&REQ0JourneyStopsZ0ID=&REQ0JourneyDate=%d.%d.%d&REQ0JourneyTime=%d:%d&REQ0HafasSearchForw=%d&existOptimizePrice=1&REQ0HafasOptimize1=0%3A1&existProductNahverkehr=yes&REQ0Tariff_TravellerAge.1=35&start=Suchen&REQ0Tariff_Class=2&REQ0Tariff_TravellerReductionClass.1=0", fromStation, toStation, day, month , year, hour, minutes, options);
-	gchar * url      = g_strdup_printf("http://mobile.bahn.de/bin/mobil/query.exe/dox?rt=1&use_realtime_filter=1&searchMode=NORMAL");
+	gchar * url      = g_strdup_printf("http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&searchMode=NORMAL");
 	gchar * result   = performCurlRequest(url, postData);
 
 	if (!result) {
@@ -324,7 +324,7 @@ ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation,
 		char *newUrl;
 
 		char *urlFrom =	strstr(result,
-				"<form action=\"//mobile.bahn.de/bin/mobil/query.exe/dox?");
+				"<form action=\"//mobile.bahn.de/bin/mobil/query.exe/eox?");
 
 		if (urlFrom) {
 
@@ -386,8 +386,6 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 
 	GArray *garray;
 
-	g_debug(returnData);
-
 	g_debug("DETAILS");
 
 	garray = g_array_new (TRUE, TRUE, sizeof (DetailItem *));
@@ -411,11 +409,25 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 
 		strcat(nbspData, detailsData);
 
+		/* bug fix for html error */
+
 		xmlDoc *doc = NULL;
 		xmlNode *root_element = NULL;
 
-		/*parse the file and get the DOM */
-		doc = xmlReadDoc(nbspData, NULL, NULL, 0);
+		char *needFix =
+					strstr(nbspData, "\" underline\" ");
+		if (needFix) {
+
+			g_debug("APPLY FIX");
+			char *parseData = stringReplace(nbspData, "\" underline\" ", "\" ");
+			/*parse the file and get the DOM */
+			doc = xmlReadDoc(parseData, NULL, NULL, 0);
+		} else {
+
+			g_debug("NO FIX");
+			/*parse the file and get the DOM */
+			doc = xmlReadDoc(nbspData, NULL, NULL, 0);
+		}
 
 		/*Get the root element node */
 		root_element = xmlDocGetRootElement(doc);
@@ -497,12 +509,12 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 								if (strcmp(sub_node->content, "") && strcmp(sub_node->content, "\n")) {
 
 									int  found = 0;
-									char *testFrom = strstr(sub_node->content, "ab ");
+									char *testFrom = strstr(sub_node->content, "dep ");
 
 									if (testFrom) {
 
 										timeFromStr = testFrom;
-										timeFromStr += 3;
+										timeFromStr += 4;
 										found = 1;
 										/* test if next element is a span */
 										sub_node2 = sub_node->next;
@@ -518,12 +530,12 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 											}
 										}
 									}
-									char *testTo = strstr(sub_node->content, "an ");
+									char *testTo = strstr(sub_node->content, "arr ");
 
 									if (testTo) {
 
 										timeToStr = testTo;
-										timeToStr += 3;
+										timeToStr += 4;
 										found = 1;
 										/* test if next element is a span */
 										sub_node2 = sub_node->next;
@@ -578,17 +590,17 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 
 							if (!strcmp(sub_node->name, "text")) {
 
-								char *testFrom = strstr(sub_node->content, "Dauer:");
-								if (testFrom) {
-
-									testFrom += 7;
-									durationStr = testFrom;
-								}
-
-								testFrom = strstr(sub_node->content, "Hinweis:");
+								char *testFrom = strstr(sub_node->content, "Duration");
 								if (testFrom) {
 
 									testFrom += 9;
+									durationStr = testFrom;
+								}
+
+								testFrom = strstr(sub_node->content, "Hint");
+								if (testFrom) {
+
+									testFrom += 5;
 									infoStr = testFrom;
 								}
 							}
@@ -817,9 +829,6 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 		}
 	}
 
-
-	g_debug("meeep");
-
 	/* RESULTS ITSELF */
 
 	char *resultDataFrom =
@@ -855,7 +864,6 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 		resultInfo->items = mobilebahnde_getResultValues(root_element->children);
 	}
 
-
 	return resultInfo;
 }
 
@@ -931,7 +939,7 @@ GArray * mobilebahnde_getResultValues(xmlNode * a_node) {
 
 						if (!strcmp(sub_node->children->name, "img")) {
 
-							if (!strcmp(sub_node->children->properties->children->content, "/v/660/img/achtung_rot_16x16.gif")) {
+							if (!strcmp(sub_node->children->properties->children->content, "/v/680/img/achtung_rot_16x16.gif")) {
 
 								resultItem->warningStr = _("<b>Warning, possible changes</b>");
 							}
